Format
======

Usage: format(image-format)

Description
-----------

This filter specifies the output format of the image. The output must be
one of: "webp", "jpeg", "gif" or "png".

Arguments
---------

image-format - The output format of the resulting image.

Example
-------

`<http://thumbor-server/filters:format(webp)/some/image.jpg>`_
